==> AGXUnreal-1.17.0_UE-5.4_Linux.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Vehicles/Tracks/FixedLinkCountBelt.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Vehicles/VehiclesForward.h>
#include <openplx/DriveTrain/DriveTrainForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics1D/Physics1DForward.h>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Vehicles/Tracks/Belt.h>
#include <openplx/Vehicles/Tracks/ContactGeometryLinkDescription.h>
/* Generated code for model FixedLinkCountBelt */
namespace openplx::Vehicles::Tracks {
    /**
     * Defines the geometrical properties of a Tracks Belt.
     * The length is the distance between each connection between links,
     * independent of the contact geometry defined for by the link_description.
     **/
    class FixedLinkCountBelt : public openplx::Vehicles::Tracks::Belt {
        protected:
            int64_t m_link_count;

        public:
            FixedLinkCountBelt();
            int64_t link_count() const;
            std::shared_ptr<openplx::Vehicles::Tracks::ContactGeometryLinkDescription> link_description() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

==> AGXUnreal-2.0.0_UE-5.7_Linux.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Vehicles/Tracks/FixedLinkCountBelt.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Vehicles/VehiclesBundleExport.h>
#include <openplx/Vehicles/VehiclesForward.h>
#include <openplx/DriveTrain/DriveTrainForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics1D/Physics1DForward.h>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Vehicles/Tracks/Belt.h>
#include <openplx/Vehicles/Tracks/ContactGeometryLinkDescription.h>

#ifdef _MSC_VER
#  pragma warning(push)
#  pragma warning(disable: 4251)
#endif

/* Generated code for model FixedLinkCountBelt */
namespace openplx::Vehicles::Tracks {
    /**
     * Defines the geometrical properties of a Tracks Belt.
     * The length is the distance between each connection between links,
     * independent of the contact geometry defined for by the link_description.
     **/
    class OPENPLX_Vehicles_BUNDLE_EXPORT FixedLinkCountBelt : public openplx::Vehicles::Tracks::Belt {
        protected:
            int64_t m_link_count;

        public:
            FixedLinkCountBelt();
            virtual ~FixedLinkCountBelt();
            int64_t link_count() const;
            std::shared_ptr<openplx::Vehicles::Tracks::ContactGeometryLinkDescription> link_description() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

#ifdef _MSC_VER
#  pragma warning(pop)
#endif
